@@ -3,18 +3,21 @@
 This plugin provides support for testing whether file-like objects are properly
 closed.
 """
-import imp
 import os
+import fnmatch
 
-from distutils.version import StrictVersion
+from distutils.version import LooseVersion
 
 import pytest
 
 try:
     import importlib.machinery as importlib_machinery
 except ImportError:
+    import imp
     importlib_machinery = None
 
+_pytest_36 = LooseVersion(pytest.__version__) >= LooseVersion("3.6")
+
 
 def pytest_addoption(parser):
 
@@ -28,6 +31,7 @@ def pytest_addoption(parser):
                   "may be specified by their base name (ignoring their full "
                   "path) or by absolute path", type="args", default=())
 
+
 def pytest_configure(config):
 
     config.getini('markers').append(
@@ -61,16 +65,17 @@ def _get_open_file_list():
 
 def pytest_runtest_setup(item):
 
-    # Retain backwards compatibility with earlier versions of pytest
-    if StrictVersion(pytest.__version__) < StrictVersion("3.6"):
-        ignore = item.get_marker('openfiles_ignore')
-    else:
-        ignore = item.get_closest_marker('openfiles_ignore')
-
     # Store a list of the currently opened files so we can compare
     # against them when the test is done.
-    if item.config.getvalue('open_files') and not ignore:
-        item.open_files = _get_open_file_list()
+    if item.config.getvalue('open_files'):
+
+        # Retain backwards compatibility with earlier versions of pytest
+        if _pytest_36:
+            ignore = item.get_closest_marker('openfiles_ignore')
+        else:
+            ignore = item.get_marker('openfiles_ignore')
+        if not ignore:
+            item.open_files = _get_open_file_list()
 
 
 def pytest_runtest_teardown(item, nextitem):
@@ -97,14 +102,19 @@ def pytest_runtest_teardown(item, nextitem):
         ignore = False
 
         for ignored in open_files_ignore:
+
+            # Note that we use fnmatch rather than re for simplicity since
+            # we are dealing with file paths - fnmatch works with the standard
+            # * and ? wildcards in paths.
+
             if not os.path.isabs(ignored):
-                if os.path.basename(filename) == ignored:
-                    ignore = True
-                    break
-            else:
-                if filename == ignored:
-                    ignore = True
-                    break
+                # Since the path is not absolute, we convert it to
+                # */<original_path> to make sure it matches absolute paths.
+                ignored = os.path.join('*', ignored)
+
+            if fnmatch.fnmatch(filename, ignored):
+                ignore = True
+                break
 
         if ignore:
             continue
